@@ -1,5 +1,5 @@
 /* This file is part of GNU Rush.                  
-   Copyright (C) 2008, 2009, 2010 Sergey Poznyakoff
+   Copyright (C) 2008-2010, 2014 Sergey Poznyakoff
 
    GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -163,7 +163,10 @@ cfck_keyword(const char *name)
 		*kw = tolower(*kw);
 	kw = str;
 	
-	if (strlen(kw) > 2 && strncmp(kw, "no", 2) == 0) {
+	if (strcmp(kw, "none") == 0) {
+		negate = 1;
+		kw = "all";
+	} else if (strlen(kw) > 2 && strncmp(kw, "no", 2) == 0) {
 		negate = 1;
 		kw += 2;
 	}
